import json
from pathlib import Path

class Localization:

    def __init__(self, lang_dir, lang="en"):
        self.lang_dir = Path(lang_dir)
        self.lang = lang
        self.translations = {}

    def available_languages(self):
        # Возвращает список доступных языков, исключая config.json
        return [file.stem for file in self.lang_dir.glob("*.json")]

    def set_language(self, lang):
        # Устанавливает новый язык, ну если он доступен.
        if lang in (langs:=self.available_languages()):
            self.lang = lang
            self._load_language()
        else:
            raise FileNotFoundError(f'Localization {lang} not found. Available: {', '.join(langs)}')

    def _load_language(self):
        # Загружает JSON-файл перевода.
        with open(self.lang_dir / f"{self.lang}.json", "r", encoding="utf-8") as file:
            self.translations = json.load(file)

    def t(self, key, **kwargs):
        # Возвращает перевод строки по ключу.
        text = self.translations.get(key, key)
        return text.format(**kwargs) if kwargs else text

    def __getitem__(self, item):  # self.i18n[KEY]
        return self.t(item)
