import json
import os.path
from .user import User


class UsersStorage:
    def __init__(self, users_file):
        self.users_file = users_file
        self._database = {
            'index': set(),
            'data': []
        }

    def save(self):
        data = []
        for user in self._database['data']:
            data.append(user.as_dict())

        with open(self.users_file, 'w') as f:
            # noinspection PyTypeChecker
            json.dump(data, f)

    def find(self, username) -> User | None:
        for u in self.list():
            if u.username == username:
                return u

    def load(self):
        if not os.path.exists(self.users_file):
            self.save()
        with open(self.users_file, 'r') as f:
            data = json.load(f)
        for row in data:
            user = User.from_dict(row)
            self._database['index'].add(user.username)
            self._database['data'].append(user)

    def add(self, user: User):
        self._database['index'].add(user.username)
        self._database['data'].append(user)
        self.save()

    def delete(self, user: User):
        if user.username not in self._database['index']:
            return
        for stored_user in self._database['data']:
            if stored_user.username != user.username:
                continue
            self._database['index'].remove(user.username)
            self._database['data'].remove(stored_user)
            self.save()
            break

    def get_index(self):
        return self._database['index'].copy()

    def list(self):
        return self._database['data'].copy()
